Class: Archaeo::Page

Inherits:
Object
  • Object
show all
Defined in:
lib/archaeo/page.rb

Overview

Model representing a fetched archived page from the Wayback Machine.

Contains the page content, metadata, and provenance information for a single archived resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(content:, content_type:, status_code:, archive_url:, original_url:, timestamp:) ⇒ Page

Returns a new instance of Page.



12
13
14
15
16
17
18
19
20
# File 'lib/archaeo/page.rb', line 12

def initialize(content:, content_type:, status_code:,
               archive_url:, original_url:, timestamp:)
  @content = content
  @content_type = content_type
  @status_code = status_code
  @archive_url = archive_url
  @original_url = original_url
  @timestamp = Timestamp.coerce(timestamp)
end

Instance Attribute Details

#archive_urlObject (readonly)

Returns the value of attribute archive_url.



9
10
11
# File 'lib/archaeo/page.rb', line 9

def archive_url
  @archive_url
end

#contentObject (readonly)

Returns the value of attribute content.



9
10
11
# File 'lib/archaeo/page.rb', line 9

def content
  @content
end

#content_typeObject (readonly)

Returns the value of attribute content_type.



9
10
11
# File 'lib/archaeo/page.rb', line 9

def content_type
  @content_type
end

#original_urlObject (readonly)

Returns the value of attribute original_url.



9
10
11
# File 'lib/archaeo/page.rb', line 9

def original_url
  @original_url
end

#status_codeObject (readonly)

Returns the value of attribute status_code.



9
10
11
# File 'lib/archaeo/page.rb', line 9

def status_code
  @status_code
end

#timestampObject (readonly)

Returns the value of attribute timestamp.



9
10
11
# File 'lib/archaeo/page.rb', line 9

def timestamp
  @timestamp
end