Class: Archaeo::PageBundle

Inherits:
Object
  • Object
show all
Defined in:
lib/archaeo/page_bundle.rb

Overview

A fetched page together with all its extracted asset URLs.

Bundles a Page with the AssetList discovered from its HTML, providing a single object for complete page archival.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(page:, assets:) ⇒ PageBundle

Returns a new instance of PageBundle.



11
12
13
14
# File 'lib/archaeo/page_bundle.rb', line 11

def initialize(page:, assets:)
  @page = page
  @assets = assets
end

Instance Attribute Details

#assetsObject (readonly)

Returns the value of attribute assets.



9
10
11
# File 'lib/archaeo/page_bundle.rb', line 9

def assets
  @assets
end

#pageObject (readonly)

Returns the value of attribute page.



9
10
11
# File 'lib/archaeo/page_bundle.rb', line 9

def page
  @page
end